@@ -1,14 +1,17 @@
 package WebService::PayPal::PaymentsAdvanced;
-$WebService::PayPal::PaymentsAdvanced::VERSION = '0.000008';
+
 use Moo;
 
+our $VERSION = '0.000009';
+
 use feature qw( say state );
 
 use Data::GUID;
 use LWP::UserAgent;
 use MooX::StrictConstructor;
 use Type::Params qw( compile );
-use Types::Standard qw( Bool HashRef InstanceOf Num Str );
+use Types::Common::String qw( NonEmptyStr );
+use Types::Standard qw( Bool HashRef InstanceOf Num );
 use Types::URI qw( Uri );
 use URI;
 use URI::FromHash qw( uri uri_object );
@@ -38,14 +41,14 @@ use WebService::PayPal::PaymentsAdvanced::Response::SecureToken;
 
 has partner => (
     is       => 'ro',
-    isa      => Str,
+    isa      => NonEmptyStr,
     required => 1,
     default  => 'PayPal',
 );
 
 has password => (
     is       => 'ro',
-    isa      => Str,
+    isa      => NonEmptyStr,
     required => 1,
 );
 
@@ -69,7 +72,7 @@ has production_mode => (
 
 has user => (
     is       => 'ro',
-    isa      => Str,
+    isa      => NonEmptyStr,
     required => 1,
 );
 
@@ -81,7 +84,7 @@ has validate_hosted_form_uri => (
 
 has vendor => (
     is       => 'ro',
-    isa      => Str,
+    isa      => NonEmptyStr,
     required => 1,
 );
 
@@ -121,7 +124,7 @@ sub _build_payflow_link_uri {
 sub capture_delayed_transaction {
     my $self = shift;
 
-    state $check = compile(Str);
+    state $check = compile(NonEmptyStr);
     my ($pnref) = $check->(@_);
 
     return $self->post( { TRXTYPE => 'D', ORIGID => $pnref } );
@@ -196,7 +199,7 @@ sub get_response_from_silent_post {
 sub inquiry_transaction {
     my $self = shift;
 
-    state $check = compile(Str);
+    state $check = compile(NonEmptyStr);
     my ($pnref) = $check->(@_);
 
     return $self->post(
@@ -223,9 +226,10 @@ sub post {
     my $http_response
         = $self->ua->post( $self->payflow_pro_uri, Content => $content );
 
-    my $params
-        = $self->_class_for('Response::FromHTTP')
-        ->new( http_response => $http_response )->params;
+    my $params = $self->_class_for('Response::FromHTTP')->new(
+        http_response => $http_response,
+        request_uri   => $self->payflow_pro_uri,
+    )->params;
 
     my $response_class = $self->_class_for('Response');
 
@@ -278,7 +282,7 @@ sub sale_from_credit_card_reference_transaction {
 
 sub _credit_card_reference_transaction {
     my $self = shift;
-    state $check = compile( Str, Str, Num );
+    state $check = compile( NonEmptyStr, NonEmptyStr, Num );
     my ( $type, $origid, $amount ) = $check->(@_);
 
     return $self->post(
@@ -303,7 +307,7 @@ sub sale_from_paypal_reference_transaction {
 
 sub _paypal_reference_transaction {
     my $self = shift;
-    state $check = compile( Str, Str, Num, Str );
+    state $check = compile( NonEmptyStr, NonEmptyStr, Num, NonEmptyStr );
     my ( $type, $baid, $amount, $currency ) = $check->(@_);
 
     return $self->post(
@@ -321,7 +325,7 @@ sub _paypal_reference_transaction {
 sub void_transaction {
     my $self = shift;
 
-    state $check = compile(Str);
+    state $check = compile(NonEmptyStr);
     my ($pnref) = $check->(@_);
 
     return $self->post( { TRXTYPE => 'V', ORIGID => $pnref } );
@@ -387,15 +391,13 @@ sub _pseudo_encode_args {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced - A simple wrapper around the PayPal Payments Advanced web service
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 SYNOPSIS
 
@@ -701,13 +703,32 @@ Returns a response object.
 
 Olaf Alders <olaf@wundercounter.com>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Greg Oschwald Mark Fowler Olaf Alders
+
+=over 4
+
+=item *
+
+Greg Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Mark Fowler <mark@twoshortplanks.com>
+
+=item *
+
+Olaf Alders <oalders@maxmind.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
