@@ -1,22 +1,12 @@
 package WebService::PayPal::PaymentsAdvanced::Error::HTTP;
-$WebService::PayPal::PaymentsAdvanced::Error::HTTP::VERSION = '0.000008';
+
 use Moo;
 
-use Types::Standard qw( InstanceOf Int );
+our $VERSION = '0.000009';
 
 extends 'Throwable::Error';
 
-has http_status => (
-    is       => 'ro',
-    isa      => Int,
-    required => 1,
-);
-
-has http_response => (
-    is       => 'ro',
-    isa      => InstanceOf ['HTTP::Response'],
-    required => 1,
-);
+with 'WebService::PayPal::PaymentsAdvanced::Error::Role::HasHTTPResponse';
 
 1;
 
@@ -26,15 +16,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Error::HTTP - An HTTP transport error
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 SYNOPSIS
 
@@ -84,16 +72,19 @@ the hosted form.
 
 Returns the HTTP status code for the response.
 
+=head2 request_uri
+
+The URI of the request that caused the HTTP error.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
