@@ -1,16 +1,12 @@
 package WebService::PayPal::PaymentsAdvanced::Error::HostedForm;
-$WebService::PayPal::PaymentsAdvanced::Error::HostedForm::VERSION = '0.000008';
+
 use Moo;
 
-use Types::Standard qw( InstanceOf );
+our $VERSION = '0.000009';
 
 extends 'Throwable::Error';
 
-has http_response => (
-    is       => 'ro',
-    isa      => InstanceOf ['HTTP::Response'],
-    required => 1,
-);
+with 'WebService::PayPal::PaymentsAdvanced::Error::Role::HasHTTPResponse';
 
 1;
 
@@ -20,15 +16,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Error::HostedForm - An error message which has been parsed out of a hosted form
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 SYNOPSIS
 
@@ -77,16 +71,23 @@ inherited from L<Throwable::Error>.
 Returns the L<HTTP::Response> object which was returned when attempting to GET
 the hosted form.
 
+=head2 http_status
+
+Returns the HTTP status code for the response.
+
+=head2 request_uri
+
+The URI of the request that caused the error.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
