@@ -1,14 +1,16 @@
 package WebService::PayPal::PaymentsAdvanced::Error::IPVerification;
-$WebService::PayPal::PaymentsAdvanced::Error::IPVerification::VERSION = '0.000008';
+
 use Moo;
 
+our $VERSION = '0.000009';
+
 extends 'Throwable::Error';
 
-use Types::Standard qw( Str );
+use Types::Common::String qw( NonEmptyStr );
 
 has ip_address => (
     is       => 'ro',
-    isa      => Str,
+    isa      => NonEmptyStr,
     required => 1,
 );
 
@@ -22,15 +24,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Error::IPVerification - A Payments Advanced IP verification error
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 SYNOPSIS
 
@@ -94,10 +94,9 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
