@@ -1,8 +1,11 @@
 package WebService::PayPal::PaymentsAdvanced::Mocker::SilentPOST;
-$WebService::PayPal::PaymentsAdvanced::Mocker::SilentPOST::VERSION = '0.000008';
+
 use Moo;
 
-use Types::Standard qw( InstanceOf Str );
+our $VERSION = '0.000009';
+
+use Types::Common::String qw( NonEmptyStr );
+use Types::Standard qw( InstanceOf );
 use WebService::PayPal::PaymentsAdvanced::Mocker::Helper;
 
 has _helper => (
@@ -15,7 +18,7 @@ has _helper => (
 
 has _secure_token_id => (
     is       => 'ro',
-    isa      => Str,
+    isa      => NonEmptyStr,
     required => 1,
     init_arg => 'secure_token_id',
 );
@@ -237,15 +240,13 @@ sub _set_defaults {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Mocker::SilentPOST - Easily mock Silent POST transactions
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 SYNOPSIS
 
@@ -297,11 +298,10 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
