@@ -1,20 +1,22 @@
 package WebService::PayPal::PaymentsAdvanced::Response;
-$WebService::PayPal::PaymentsAdvanced::Response::VERSION = '0.000008';
+
 use Moo;
 
-use Types::Standard qw( Str );
+our $VERSION = '0.000009';
+
+use Types::Common::String qw( NonEmptyStr );
 use WebService::PayPal::PaymentsAdvanced::Error::Authentication;
 use WebService::PayPal::PaymentsAdvanced::Error::Generic;
 
 has pnref => (
     is      => 'lazy',
-    isa     => Str,
+    isa     => NonEmptyStr,
     default => sub { shift->params->{PNREF} },
 );
 
 has ppref => (
     is      => 'lazy',
-    isa     => Str,
+    isa     => NonEmptyStr,
     default => sub { shift->params->{PPREF} },
 );
 
@@ -48,15 +50,13 @@ sub BUILD {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Response - Generic response object
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 SYNOPSIS
 
@@ -101,11 +101,10 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
