@@ -1,10 +1,13 @@
 package WebService::PayPal::PaymentsAdvanced::Response::FromHTTP;
-$WebService::PayPal::PaymentsAdvanced::Response::FromHTTP::VERSION = '0.000008';
+
 use Moo;
 
+our $VERSION = '0.000009';
+
 use MooX::HandlesVia;
 use MooX::StrictConstructor;
 use Types::Standard qw( HashRef InstanceOf );
+use Types::URI qw( Uri );
 use URI;
 use URI::QueryParam;
 use WebService::PayPal::PaymentsAdvanced::Error::HTTP;
@@ -25,6 +28,14 @@ has _http_response => (
     handles  => { _code => 'code', _content => 'content', },
 );
 
+has _request_uri => (
+    init_arg => 'request_uri',
+    is       => 'ro',
+    isa      => Uri,
+    coerce   => 1,
+    required => 1,
+);
+
 sub BUILD {
     my $self = shift;
     return if $self->_http_response->is_success;
@@ -33,6 +44,7 @@ sub BUILD {
         message       => 'HTTP error: ' . $self->_code,
         http_response => $self->_http_response,
         http_status   => $self->_code,
+        request_uri   => $self->_request_uri,
     );
 }
 
@@ -46,15 +58,13 @@ sub _build_params {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Response::FromHTTP - Response object for WebService::PayPal::PaymentsAdvanced instantiated from HTTP::Response object
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 DESCRIPTION
 
@@ -88,11 +98,10 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
