@@ -1,11 +1,14 @@
 package WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST;
-$WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST::VERSION = '0.000008';
+
 use Moo;
 
+our $VERSION = '0.000009';
+
 use List::AllUtils qw( any );
 use MooX::HandlesVia;
 use MooX::StrictConstructor;
-use Types::Standard qw( Bool HashRef Str );
+use Types::Common::String qw( NonEmptyStr );
+use Types::Standard qw( Bool HashRef );
 use WebService::PayPal::PaymentsAdvanced::Error::IPVerification;
 
 extends 'WebService::PayPal::PaymentsAdvanced::Response';
@@ -26,7 +29,7 @@ sub BUILD {
 
 has _ip_address => (
     is        => 'ro',
-    isa       => Str,
+    isa       => NonEmptyStr,
     init_arg  => 'ip_address',
     required  => 0,
     predicate => '_has_ip_address',
@@ -71,15 +74,13 @@ sub _build_ip_address_is_verified {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Response::FromSilentPOST - Response object generated via Silent POST params
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 DESCRIPTION
 
@@ -123,11 +124,10 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
