@@ -1,7 +1,9 @@
 package WebService::PayPal::PaymentsAdvanced::Response::Sale;
-$WebService::PayPal::PaymentsAdvanced::Response::Sale::VERSION = '0.000008';
+
 use Moo;
 
+our $VERSION = '0.000009';
+
 extends 'WebService::PayPal::PaymentsAdvanced::Response';
 
 with 'WebService::PayPal::PaymentsAdvanced::Role::HasTransactionTime',
@@ -11,15 +13,13 @@ with 'WebService::PayPal::PaymentsAdvanced::Role::HasTransactionTime',
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Response::Sale - Response class for Sale transactions
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 DESCRIPTION
 
@@ -27,7 +27,7 @@ Response class for Sale transactions C<TRXTYPE=S>  You should not create this
 response object directly. This module inherits from
 L<WebService::PayPal::PaymentsAdvanced::Response> and includes the methods
 provided by L<WebService::PayPal::PaymentsAdvanced::Role::HasTransactionTime>
-and L<WebService::PayPal::PaymentsAdvanced::Role::HasTransactionTender>.
+and L<WebService::PayPal::PaymentsAdvanced::Role::HasTender>.
 
 =head1 AUTHOR
 
@@ -35,11 +35,10 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
