@@ -1,7 +1,9 @@
 package WebService::PayPal::PaymentsAdvanced::Response::SecureToken;
-$WebService::PayPal::PaymentsAdvanced::Response::SecureToken::VERSION = '0.000008';
+
 use Moo;
 
+our $VERSION = '0.000009';
+
 use feature qw( state );
 
 extends 'WebService::PayPal::PaymentsAdvanced::Response';
@@ -58,6 +60,7 @@ sub _build_hosted_form_uri {
             message       => "hosted_form URI does not validate: $uri",
             http_response => $res,
             http_status   => $res->code,
+            request_uri   => $uri,
         );
 
     }
@@ -74,6 +77,8 @@ sub _build_hosted_form_uri {
         message =>
             "hosted_form contains error message: $scraped_text->{error}",
         http_response => $res,
+        http_status   => $res->code,
+        request_uri   => $uri,
     );
 }
 
@@ -81,15 +86,13 @@ sub _build_hosted_form_uri {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Response::SecureToken - Response class for creating secure tokens
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 SYNOPSIS
 
@@ -147,11 +150,10 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
