@@ -1,19 +1,21 @@
 package WebService::PayPal::PaymentsAdvanced::Role::HasCreditCard;
-$WebService::PayPal::PaymentsAdvanced::Role::HasCreditCard::VERSION = '0.000008';
+
 use Moo::Role;
 
+our $VERSION = '0.000009';
+
 use Types::Common::Numeric qw( PositiveInt );
-use Types::Standard qw( Str );
+use Types::Common::String qw( NonEmptyStr );
 
 has card_type => (
     is       => 'lazy',
-    isa      => Str,
+    isa      => NonEmptyStr,
     init_arg => undef,
 );
 
 has card_expiration => (
     is       => 'lazy',
-    isa      => Str,
+    isa      => NonEmptyStr,
     init_arg => undef,
 );
 
@@ -26,7 +28,7 @@ has card_last_four_digits => (
 
 has reference_transaction_id => (
     is       => 'lazy',
-    isa      => Str,
+    isa      => NonEmptyStr,
     init_arg => undef,
     default  => sub { shift->pnref },
 );
@@ -59,15 +61,13 @@ sub _build_card_expiration {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Role::HasCreditCard - Role which provides methods specifically for credit card transactions
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head2 card_type
 
@@ -84,7 +84,7 @@ A human readable credit card type.  One of:
 
 The month and year of the credit card expiration.
 
-=head card_last_four_digits
+=head2 card_last_four_digits
 
 The last four digits of the credit card.
 
@@ -98,11 +98,10 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
