@@ -1,12 +1,14 @@
 package WebService::PayPal::PaymentsAdvanced::Role::HasMessage;
-$WebService::PayPal::PaymentsAdvanced::Role::HasMessage::VERSION = '0.000008';
+
 use Moo::Role;
 
-use Types::Standard qw( Str );
+our $VERSION = '0.000009';
+
+use Types::Common::String qw( NonEmptyStr );
 
 has message => (
     is       => 'lazy',
-    isa      => Str,
+    isa      => NonEmptyStr,
     init_arg => undef,
 );
 
@@ -19,15 +21,13 @@ sub _build_message {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Role::HasMessage - Role which provides message attribute to exception and response classes.
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head1 AUTHOR
 
@@ -35,11 +35,10 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
