@@ -1,18 +1,20 @@
 package WebService::PayPal::PaymentsAdvanced::Role::HasTokens;
-$WebService::PayPal::PaymentsAdvanced::Role::HasTokens::VERSION = '0.000008';
+
 use Moo::Role;
 
-use Types::Standard qw( Str );
+our $VERSION = '0.000009';
+
+use Types::Common::String qw( NonEmptyStr );
 
 has secure_token => (
     is       => 'lazy',
-    isa      => Str,
+    isa      => NonEmptyStr,
     init_arg => undef,
 );
 
 has secure_token_id => (
     is       => 'lazy',
-    isa      => Str,
+    isa      => NonEmptyStr,
     init_arg => undef,
 );
 
@@ -30,15 +32,13 @@ sub _build_secure_token_id {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 WebService::PayPal::PaymentsAdvanced::Role::HasTokens - Provides roles for dealing with secure tokens
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head2 secure_token
 
@@ -54,11 +54,10 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
